@@ -30,12 +30,13 @@ def set_global_verbose(val:bool):
 
 def set_default_format(fmt:str):
     logging_config.default_format = fmt
-    init_logger()
+    logging_config.stream_handler.setFormatter(logging_config.TransparaCustomLogFormatter())
 
 def set_tdebug_format(fmt:str):
     logging_config.debug_handler_format = fmt
-    init_logger()
+    logging_config.stream_handler.setFormatter(logging_config.TransparaCustomLogFormatter())
 
 def set_terror_format(fmt:str):
     logging_config.error_handler_format = fmt 
-    init_logger()
+    logging_config.stream_handler.setFormatter(logging_config.TransparaCustomLogFormatter())
+
